{"00000:1": "

    {% macro menu() %}\n<ul>\n{% for dirname in sorted(navigation.directories[1]) -%}\n{% set subdirs = navigation.directories[1][dirname] -%}\n\n{% if navigation.current_index == dirname -%}\n{% set liclass = 'active' -%}\n{% else -%}\n{% set liclass = '' -%}\n{% endif -%}\n\n<li class="{{ liclass }}"><a href="/{{ dirname }}">{{ dirname.capitalize() }}</a></li>\n{% endfor -%}\n\n\n{% endmacro %}\n

\n"}